@@ -2,7 +2,7 @@ package Parse::Taxonomy;
 use strict;
 use Carp;
 use Scalar::Util qw( reftype );
-our $VERSION = '0.20';
+our $VERSION = '0.21';
 
 =head1 NAME
 
@@ -10,8 +10,8 @@ Parse::Taxonomy - Validate hierarchical data stored in CSV format
 
 =head1 VERSION
 
-This document refers to version 0.20 of Parse::Taxonomy.  This version was
-released November 13 2015.
+This document refers to version 0.21 of Parse::Taxonomy.  This version was
+released December 21 2015.
 
 =head1 SYNOPSIS
 
@@ -338,7 +338,7 @@ or through the web interface at L<http://rt.cpan.org>.
 James E. Keenan (jkeenan@cpan.org).  When sending correspondence, please
 include 'Parse::Taxonomy' or 'Parse-Taxonomy' in your subject line.
 
-Creation date:  May 24 2015.  Last modification date:  November 13 2015.
+Creation date:  May 24 2015.  Last modification date:  December 21 2015.
 
 Development repository: L<https://github.com/jkeenan/parse-taxonomy>
 
